@@ -1758,7 +1758,13 @@ class Model:
         Examples
         --------
 
-        >>> m.export_to_mps('my_problem.mps')
+        - Writing a linear optimization or mixed integer linear optimization model into MPS file
+          
+          >>> m.export_mps('my_problem.mps')
+
+        - Returning the MPS string as a Python variable
+          
+          >>> m.export_mps(fetch=True)
 
         """
         if self._is_linear():
