@@ -48,6 +48,9 @@ class TestCreateData(unittest.TestCase):
             warnings.warn('CAS connection is not available', RuntimeWarning)
         except TypeError:
             warnings.warn('CAS variables are not available', RuntimeWarning)
+        except ValueError:
+            print("Protocol error, version info:", sys.version_info)
+            raise unittest.SkipTest('Protocol is not available for testing')
 
     @classmethod
     def tearDownClass(cls):
@@ -271,6 +274,8 @@ class TestCreateData(unittest.TestCase):
         w.submit()
         self.assertEqual(
             session.CASTable('example').to_frame().to_string(), cleandoc('''
+            Selected Rows from Table EXAMPLE
+            
                  i   xa   xb   xc
             0  1.0  2.0  2.0  2.0
             1  2.0  2.0  2.0  2.0
@@ -337,12 +342,16 @@ class TestCreateData(unittest.TestCase):
         w.submit()
         response = session.CASTable('out').to_frame()
         self.assertEqual(response.to_string(), cleandoc('''
+            Selected Rows from Table OUT
+
                  i   a1   a2   a3    a4    b
             0  2.0  2.0  4.0  6.0   8.0  4.0
             1  3.0  3.0  6.0  9.0  12.0  9.0'''))
 
         response2 = cd.get_response()
         self.assertEqual(response2.to_string(), cleandoc('''
+            Selected Rows from Table OUT
+            
                  i   a1   a2   a3    a4    b
             0  2.0  2.0  4.0  6.0   8.0  4.0
             1  3.0  3.0  6.0  9.0  12.0  9.0'''))
