@@ -44,6 +44,9 @@ class TestReadData(unittest.TestCase):
             warnings.warn('CAS connection is not available', RuntimeWarning)
         except TypeError:
             warnings.warn('CAS variables are not available', RuntimeWarning)
+        except ValueError:
+            print("Protocol error, version info:", sys.version_info)
+            raise unittest.SkipTest('Protocol is not available for testing')
 
     @classmethod
     def tearDownClass(cls):
@@ -241,6 +244,8 @@ class TestReadData(unittest.TestCase):
         ws.submit(verbose=True)
         self.assertEqual(ws.response['Print1.PrintTable'].to_string(), cleandoc(
             """
+            Print Table
+            
                COL1    p    q
             0   1.0  1.0  2.0
             1   2.0  3.0  4.0
